pub struct GaugeValue {
pub last: GaugeType,
pub min: GaugeType,
pub max: GaugeType,
pub sum: GaugeType,
pub count: u64,
}Expand description
A snapshot of values within a Bucket.
Fields
last: GaugeTypeThe last value reported in the bucket.
This aggregation is not commutative.
min: GaugeTypeThe minimum value reported in the bucket.
max: GaugeTypeThe maximum value reported in the bucket.
sum: GaugeTypeThe sum of all values reported in the bucket.
count: u64The number of times this bucket was updated with a new value.
Implementations
Sourceimpl GaugeValue
impl GaugeValue