Struct UnixTimestamp
pub struct UnixTimestamp(/* private fields */);Expand description
A unix timestamp (full seconds elapsed since 1970-01-01 00:00 UTC).
Implementations
impl UnixTimestamp
impl UnixTimestamp
pub const fn from_secs(secs: u64) -> UnixTimestamp
pub const fn from_secs(secs: u64) -> UnixTimestamp
Creates a unix timestamp from the given number of seconds.
pub fn from_system(time: SystemTime) -> UnixTimestamp
pub fn from_system(time: SystemTime) -> UnixTimestamp
Creates a unix timestamp from the given system time.
pub fn from_datetime(
date_time: DateTime<impl TimeZone>,
) -> Option<UnixTimestamp>
pub fn from_datetime( date_time: DateTime<impl TimeZone>, ) -> Option<UnixTimestamp>
Creates a unix timestamp from the given chrono DateTime.
Returns Some if this is a valid date time starting with 1970-01-01 00:00 UTC. If the date
lies before the UNIX epoch, this function returns None.
pub fn from_instant(instant: Instant) -> UnixTimestamp
pub fn from_instant(instant: Instant) -> UnixTimestamp
Converts the given Instant into a UNIX timestamp.
This is done by comparing the Instant with the current system time. Note that the system
time is subject to skew, so subsequent calls to from_instant may return different values.
pub fn now() -> UnixTimestamp
pub fn now() -> UnixTimestamp
Returns the current timestamp.
pub fn as_nanos(self) -> u64
pub fn as_nanos(self) -> u64
Returns the number of nanoseconds since the UNIX epoch start. Precision limited to seconds.
pub fn as_datetime(self) -> Option<DateTime<Utc>>
pub fn as_datetime(self) -> Option<DateTime<Utc>>
Returns the timestamp as chrono datetime.